#
# spec file for package freshplayerplugin
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_with restricted
Name:           freshplayerplugin
Version:        0.3.11
Release:        bp156.4.7
Summary:        PPAPI2NPAPI compatibility layer
License:        MIT
Group:          Productivity/Networking/Web/Browsers
URL:            https://github.com/i-rinat/freshplayerplugin
Source:         https://github.com/i-rinat/freshplayerplugin/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
# PATCH-FIX-OPENSUSE freshplayerplugin-drop-angle.patch bsc#937244 i@marguerite.su
Patch0:         freshplayerplugin-drop-angle.patch
# PATCH-FIX-UPSTREAM freshplayerplugin-fix-no-hwdec.patch -- Fix compilation with no hardware acceleration.
Patch1:         freshplayerplugin-fix-no-hwdec.patch
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  ragel
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glesv2)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(icu-uc)
BuildRequires:  pkgconfig(jack)
BuildRequires:  pkgconfig(libdrm)
BuildRequires:  pkgconfig(libevent)
BuildRequires:  pkgconfig(libevent_pthreads)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(libv4l2)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(pango)
BuildRequires:  pkgconfig(pangocairo)
BuildRequires:  pkgconfig(pangoft2)
BuildRequires:  pkgconfig(soxr)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xcursor)
BuildRequires:  pkgconfig(xrandr)
BuildRequires:  pkgconfig(xrender)
Supplements:    (browser(npapi) and flash-player-ppapi)
Conflicts:      flash-player
%if 0%{with restricted}
# Hardware accelerated decoding.
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavutil)
BuildRequires:  pkgconfig(libva)
BuildRequires:  pkgconfig(libva-x11)
BuildRequires:  pkgconfig(vdpau)
Requires:       flash-player-ppapi
Provides:       flash-plugin
%else
Recommends:     flash-player-ppapi
%endif
%ifarch armv6l || armv6hl
BuildRequires:  Mesa-libEGL-devel
BuildRequires:  Mesa-libEGL1
BuildRequires:  Mesa-libGLESv1_CM-devel
BuildRequires:  Mesa-libGLESv1_CM1
BuildRequires:  Mesa-libGLESv2-2
BuildRequires:  Mesa-libGLESv2-devel
%endif

%description
The main goal of this project is to get PPAPI (Pepper) Flash player
working in Firefox. This wrapper implements some kind of adapter
which will look like browser to PPAPI plugin and look like NPAPI
plugin for browser.

%prep
%autosetup -p1

# Enable hardware accelerated decoding for PMBS.
%if %{with restricted}
sed -i 's|^\(enable_hwdec = \)0|\11|' data/freshwrapper.conf.example
%endif

%build
%cmake \
  -DMOZPLUGIN_INSTALL_DIR=%{_libdir}/browser-plugins \
%if %{with restricted}
  -DWITH_HWDEC=1  \
%else
  -DWITH_HWDEC=0  \
%endif
  -DWITH_GLES2=ON
%make_build

%install
%cmake_install
install -Dpm 0644 data/freshwrapper.conf.example \
  %{buildroot}%{_sysconfdir}/freshwrapper.conf

%post
/sbin/ldconfig
# A tweak for Plasma 5.
if [ ! -f "%{_bindir}/plasmashell" ]; then
    sed -i 's|^\(quirk_plasma5_screensaver = \)0$|\11|' %{_sysconfdir}/freshwrapper.conf
fi

%postun -p /sbin/ldconfig

%files
%license COPYING LICENSE
%doc ChangeLog README.md
%config %{_sysconfdir}/freshwrapper.conf
%{_libdir}/browser-plugins/libfreshwrapper-flashplayer.so

%changelog
* Thu Aug 19 2021 Jan Engelhardt <jengelh@inai.de>
- Switch from ragel6 to ragel7
* Sat Feb 22 2020 Alexei Sorokin <sor.alexei@meowr.ru>
- Require flash-player-ppapi instead of chromium-pepper-flash.
* Tue Oct 29 2019 Luigi Baldoni <aloisio@gmx.com>
- Fix Factory build
* Thu Sep 12 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.3.11
  * misc: build compatibility with newer FFmpeg (AV-prefixed
    macros);
  * misc: stop using __thread for thread-local variables;
  * graphics: add explicit fullscreen window position
    configuration;
  * misc: fix tests on big-endian machines;
  * misc: mention that v0.3.10 existed, but without a changelog
    entry.
* Tue Aug 14 2018 sor.alexei@meowr.ru
- Update to version 0.3.9 (changes since 0.3.7):
  * misc: Add NPN_PluginThreadAsyncCall emulation for Firefox 58.
  * network: Stop using files with NPN_PostURL.
- Add freshplayerplugin-fix-no-hwdec.patch: Fix compilation with no
  hardware acceleration.
* Tue Aug  1 2017 i@marguerite.su
- Due to redhat#1402582, ragel's colm can't build and core dumps
  on non-x86_64 arch. As ragel is just a code generator, we
  can downgrade the buildrequires to ragel-6 (6.10) with no harm.
* Sun Jun  4 2017 sor.alexei@meowr.ru
- Update to version 0.3.7:
  * graphics: Add more fullscreen _NET_WM controls.
  * misc: drop libpdf and NaCl wrappers.
  * misc: Search for PepperFlash in Chrome component update
    directories.
* Thu Nov 17 2016 sor.alexei@meowr.ru
- Update to version 0.3.6:
  * graphics: Fix the off-by-one pixel issue in fullscreen scaling
    mode.
  * graphics: Try to flicker less.
  * misc: Use ICU for character set conversion, use WhatWG
    canonical encoding name conversion.
  * misc: Guess the default character encoding from a locale name.
  * misc: Guess GTK+ major version at run time.
- Rename clean.patch to freshplayerplugin-drop-angle.patch and
  simplify to ease maintainership.
* Sun Jul  3 2016 mpluskal@suse.com
- Conflict with flash-player as having them both installed is
  confusing firefox
* Tue Apr 26 2016 hpj@urpla.net
- Update to v0.3.5:
  * video: try /dev/video* instead of /dev/v4l/by-path/*
  * network: fix byte order in PPB_NetAddress
  * network: partially implement PPB_HostResolver;1.0 and
  PPB_UDPSocket;1.2
  * mics: keep task order in PPB_MessageLoop
- refresh clean patch
* Sat Dec 26 2015 mpluskal@suse.com
- Use cmake macro
* Sat Dec 26 2015 sor.alexei@meowr.ru
- Update to 0.3.4:
  * graphics: add non-XRender fallback paths.
  * graphics: use ANGLE GLES2 emulation layer by default.
  * graphics: restore mouse pointer when moved outside.
  * audio: request reduced latency when capturing via PulseAudio.
  * input: detect and handle mouse double clicks.
  * misc: add `make install` rule.
  * misc: add option to show version in context menu.
  * misc: call gdb for crash debugging.
  * misc: stop using -fvisibility directives.
- Use system libGLESv2.
- Rebase clean.patch.
- Remove cmake-install.patch: hardly reasonable now.
- Remove Chromium Pepper Flash path appending: handled upstream.
* Fri Nov  6 2015 sor.alexei@meowr.ru
- Provide flash-plugin instead of flash-player in PMBS.
- Install freshplayerplugin if both MozillaFirefox and
  chromium-pepper-flash are installed.
* Mon Oct  5 2015 sor.alexei@meowr.ru
- Update to 0.3.3:
  * graphics: update fullscreen size at the very end of transition.
  * net: implement PPB_NetAddress;1.0 inferface.
  * audio: add "noaudio" backend which only provide sync events.
  * misc: track origin threads of callbacks.
  * misc: drop libconfig dependency, use own config parser.
  * misc: avoid calling Javascript in NPP_SetWindow().
  * misc: fix -fvisibility=hidden build issue.
  * misc: rename file name to libfreshwrapper-flashplayer.so.
- Rebase clean.patch and cmake-install.patch.
* Mon Sep 21 2015 olaf@aepfle.de
- Add BuildRequires pkgconfig(vdpau)
* Tue Aug 18 2015 sor.alexei@meowr.ru
- Update to 0.3.2:
  * Fix fullscreen geometry issues (black screen with a tiny video
    in top left corner).
  * Synchronize with vertical blank in fullscreen mode.
  * Add autoconnect and server autostart configuration for JACK
    output.
  * Add NPAPI:AudioControl support.
- Do not build libpdf and NaCl plugins after all as they do not
  work (placeholders).
* Sat Aug  1 2015 sor.alexei@meowr.ru
- Don't provide flash-player outside PMBS to prevent accidental
  install with a possible lack of chromium-pepper-flash.
* Thu Jul 23 2015 sor.alexei@meowr.ru
- Update to 0.3.1:
  * Add video decoding through VDPAU.
  * Bugfixes.
* Wed Jul  8 2015 i@marguerite.su
- add clean.patch
  * 3rdparty/angle has license problem, so strip it from source
    fix boo#937244
* Mon Jul  6 2015 olaf@aepfle.de
- Disable Gtk3 support, it is not used
* Fri Jun 26 2015 olaf@aepfle.de
- Use pkgconfig as BuildRequires because it is used by cmake
* Sat Jun 13 2015 i@marguerite.su
- merge changelog w/ packman's. prepared for linking.
- add cmake-install.patch for installation options
- configuraion tweaks
  * src/config_pepperflash.c modification is outdated.
  * use append intead of replace for pepperflash_path,
    in case some users have Google Chrome installed.
  * enable hardware decoding for packman builds
  * enable KDE Plasma 5 option after package installaion.
- build libpdf.so and nacl plguins too
* Thu Jun 11 2015 sor.alexei@meowr.ru
- Update to 0.3.0:
  * Add audio capture support.
  * Implement UDP sockets and host resolver interfaces.
  * Stop postponing already started screen saver.
  * Implement custom cursors.
  * Add GLES2 shader translator from ANGLE.
  * Add video capture support.
  * Add H.264 video decode via VA-API.
- Switch to Gtk3.
* Sun Apr 26 2015 sor.alexei@meowr.ru
- Update to 0.2.4:
  * 3D (accelerated rendering) is enabled by default.
  * IMEs support (ibus and fcitx were tested).
  * Mouse wheel events support.
  * Screensaver inhibition fixes.
  * Playing audio through JACK.
  * High DPI screens support via device_scale parameter.
* Tue Feb 17 2015 sor.alexei@meowr.ru
- Update to 0.2.3:
  * Various bugfixes.
  * Implement ppb_x509_certificate interface (is required by
    prezi.com).
* Tue Jan 13 2015 sor.alexei@meowr.ru
- Update to 0.2.2:
  * Implement Flash DRM interface (Desktop PepperFlash does not
    use it, you need one from ChromeOS).
  * Fix malfunctioning nested submenus.
  * Implement file chooser dialog.
  * Fullscreen fixups, stop crashing on Alt-F4.
  * Rework ALSA code, add optional PulseAudio support.
  * Implement screen saver inhibition interface.
  * Use GLX to create GL context, for both GL and GLES.
  * Fix hangs caused by wrong nested message loop handling.
  * Add quiet config option to decrease amount of output.
  * Fix Referer bug.
- Build freshplayerplugin with libpulse.
- Fix path to Pepper Flash in library itself as well.
* Sat Dec 13 2014 joerg.lorenzen@ki.tng.de
- Removed some unneeded dependencies to enable build on
  armv6l/armv6hl.
* Thu Dec 11 2014 joerg.lorenzen@ki.tng.de
- Update to 0.2.1.git20141204:
  * Fix indentation.
  * Remove xinerama from dependencies.
  * Added dependencies to enable build on ARM CPU.
* Thu Oct 23 2014 dmitry_r@opensuse.org
- Update to 0.2.1:
  * No changelog available.
* Sat Sep  6 2014 dmitry_r@opensuse.org
- Update to 0.2:
  * No changelog available.
* Sun May 18 2014 sor.alexei@meowr.ru
- Initial package.
